diff --git a/beat/core/dock.py b/beat/core/dock.py
index c5151887d18d941413151ee7e2aeaf363661a879..37ecfd76ece247352e3c4440d1d0693303664be1 100755
--- a/beat/core/dock.py
+++ b/beat/core/dock.py
@@ -143,8 +143,12 @@ class Host(object):
     retval = {}
 
     for image in self.client.images():
       # call the "describe" application on each existing image
       tag = image['RepoTags'][0] if image['RepoTags'] else None
+      if (tag is None) or (tag.find('beat') == -1):
+        continue
+
       id = image['Id'].split(':')[1][:12]
       logger.debug("Checking image `%s' (%s)...", tag, id)
       description = _describe(tag or id)
@@ -143,8 +143,12 @@ class Host(object):
 
     for image in self.client.images():
-      # call the "describe" application on each existing image
+      # call the "describe" application on each existing image with "beat" in
+      # its name
       tag = image['RepoTags'][0] if image['RepoTags'] else None